@@ -9,6 +9,8 @@
 
 #include "kcoreurlnavigator.h"
 
+#include "urlutil_p.h"
+
 #include <KIO/StatJob>
 #include <KLocalizedString>
 #include <kfileitem.h>
@@ -18,7 +20,6 @@
 #include <QMimeData>
 #include <QMimeDatabase>
 
-#include "../filewidgets/urlutil_p.h"
 #include <algorithm>
 #include <numeric>
 
@@ -33,7 +34,8 @@ public:
     KCoreUrlNavigatorPrivate(KCoreUrlNavigator *qq);
 
     ~KCoreUrlNavigatorPrivate()
-    { }
+    {
+    }
 
     /**
      * Returns true, if the MIME type of the path represents a
@@ -84,11 +86,11 @@ int KCoreUrlNavigatorPrivate::adjustedHistoryIndex(int historyIndex) const
 
 // ------------------------------------------------------------------------------------------------
 
-KCoreUrlNavigator::KCoreUrlNavigator(const QUrl& url, QObject *parent)
+KCoreUrlNavigator::KCoreUrlNavigator(const QUrl &url, QObject *parent)
     : QObject(parent)
     , d(new KCoreUrlNavigatorPrivate(this))
 {
-    d->m_history.prepend(LocationData{url.adjusted(QUrl::NormalizePathSegments)});
+    d->m_history.prepend(LocationData{url.adjusted(QUrl::NormalizePathSegments), {}});
 }
 
 KCoreUrlNavigator::~KCoreUrlNavigator()
@@ -227,7 +229,7 @@ void KCoreUrlNavigator::setCurrentLocationUrl(const QUrl &newUrl)
     }
 
     Q_ASSERT(d->m_historyIndex == 0);
-    d->m_history.insert(0, LocationData{url});
+    d->m_history.insert(0, LocationData{url, {}});
 
     // Prevent an endless growing of the history: remembering
     // the last 100 Urls should be enough...
